=== modified file 'drizzled/main.cc'
--- drizzled/main.cc	2011-03-14 16:41:31 +0000
+++ drizzled/main.cc	2011-03-15 20:23:53 +0000
@@ -110,7 +110,7 @@
     if (! (session->lex().current_select &&
            session->lex().current_select->no_error && !session->is_fatal_error))
     {
-      if (! session->main_da.is_error())            // Return only first message
+      if (! session->main_da().is_error())            // Return only first message
       {
         if (error == EE_OK)
           error= ER_UNKNOWN_ERROR;
@@ -118,7 +118,7 @@
         if (str == NULL)
           str= ER(error);
 
-        session->main_da.set_error_status(error, str);
+        session->main_da().set_error_status(error, str);
       }
     }
 

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-03-15 19:49:57 +0000
+++ drizzled/session.cc	2011-03-15 20:23:53 +0000
@@ -147,6 +147,7 @@
 class Session::impl_c
 {
 public:
+  Diagnostics_area diagnostics;
   /**
     The lex to hold the parsed tree of conventional (non-prepared) queries.
     Whereas for prepared and stored procedure statements we use an own lex
@@ -270,6 +271,11 @@
   plugin::EventObserver::registerSessionEvents(*this);
 }
 
+Diagnostics_area& Session::main_da()
+{
+  return impl_->diagnostics;
+}
+
 const LEX& Session::lex() const
 {
   return impl_->lex;
@@ -349,7 +355,7 @@
     return m_internal_handler->handle_error(sql_errno, message, level, this);
   }
 
-  return false;                                 // 'false', as per coding style
+  return false;
 }
 
 void Session::setAbort(bool arg)
@@ -745,7 +751,7 @@
   */
   lex().current_select= 0;
   clear_error();
-  main_da.reset_diagnostics_area();
+  main_da().reset_diagnostics_area();
 
   if (client->readCommand(&l_packet, &packet_length) == false)
   {
@@ -1714,7 +1720,7 @@
                   , (_schema->empty() ? "unconnected" : _schema->c_str())
                   , security_ctx->username().empty() == false ? security_ctx->username().c_str() : "unauthenticated"
                   , security_ctx->address().c_str()
-                  , (main_da.is_error() ? main_da.message() : ER(ER_UNKNOWN_ERROR)));
+                  , (main_da().is_error() ? main_da().message() : ER(ER_UNKNOWN_ERROR)));
     }
   }
 
@@ -1747,7 +1753,7 @@
                           SERVER_QUERY_NO_GOOD_INDEX_USED);
 
   clear_error();
-  main_da.reset_diagnostics_area();
+  main_da().reset_diagnostics_area();
   total_warn_count=0;			// Warnings for this query
   sent_row_count= examined_row_count= 0;
 }
@@ -1936,9 +1942,9 @@
    */
   {
     TransactionServices &transaction_services= TransactionServices::singleton();
-    main_da.can_overwrite_status= true;
+    main_da().can_overwrite_status= true;
     transaction_services.autocommitOrRollback(*this, is_error());
-    main_da.can_overwrite_status= false;
+    main_da().can_overwrite_status= false;
     transaction.stmt.reset();
   }
 
@@ -2112,12 +2118,65 @@
 table::Singular *Session::getInstanceTable(List<CreateField> &field_list)
 {
   temporary_shares.push_back(new table::Singular(this, field_list)); // This will not go into the tableshare cache, so no key is used.
-
-  table::Singular *tmp_share= temporary_shares.back();
-
-  assert(tmp_share);
-
-  return tmp_share;
+  return temporary_shares.back();
+}
+
+void Session::clear_error(bool full)
+{
+  if (main_da().is_error())
+    main_da().reset_diagnostics_area();
+
+  if (full)
+  {
+    drizzle_reset_errors(this, true);
+  }
+}
+
+void Session::clearDiagnostics()
+{
+  main_da().reset_diagnostics_area();
+}
+
+/**
+  Mark the current error as fatal. Warning: this does not
+  set any error, it sets a property of the error, so must be
+  followed or prefixed with my_error().
+*/
+void Session::fatal_error()
+{
+  assert(main_da().is_error());
+  is_fatal_error= true;
+}
+
+/**
+  true if there is an error in the error stack.
+
+  Please use this method instead of direct access to
+  net.report_error.
+
+  If true, the current (sub)-statement should be aborted.
+  The main difference between this member and is_fatal_error
+  is that a fatal error can not be handled by a stored
+  procedure continue handler, whereas a normal error can.
+
+  To raise this flag, use my_error().
+*/
+bool Session::is_error() const 
+{ 
+  return impl_->diagnostics.is_error(); 
+}
+
+/** A short cut for session->main_da().set_ok_status(). */
+void Session::my_ok(ha_rows affected_rows, ha_rows found_rows_arg, uint64_t passed_id, const char *message)
+{
+  main_da().set_ok_status(this, affected_rows, found_rows_arg, passed_id, message);
+}
+
+/** A short cut for session->main_da().set_eof_status(). */
+
+void Session::my_eof()
+{
+  main_da().set_eof_status(this);
 }
 
 namespace display  {

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-03-15 20:03:35 +0000
+++ drizzled/session.h	2011-03-15 20:23:53 +0000
@@ -32,8 +32,6 @@
 #include <sys/resource.h>
 #include <sys/time.h>
 
-// #include <drizzled/catalog/instance.h>
-// #include <drizzled/cursor.h>
 #include <drizzled/diagnostics_area.h>
 #include <drizzled/error.h>
 #include <drizzled/identifier.h>
@@ -203,6 +201,7 @@
   }
 
 public:
+  Diagnostics_area& main_da();
   const LEX& lex() const;
   LEX& lex();
   enum_sql_command getSqlCommand() const;
@@ -608,7 +607,7 @@
   List<DRIZZLE_ERROR> warn_list;
   uint32_t warn_count[(uint32_t) DRIZZLE_ERROR::WARN_LEVEL_END];
   uint32_t total_warn_count;
-  Diagnostics_area main_da;
+  Diagnostics_area main_da0;
 
   ulong col_access;
 
@@ -1094,53 +1093,11 @@
 
   int send_explain_fields(select_result *result);
 
-  /**
-    Clear the current error, if any.
-    We do not clear is_fatal_error or is_fatal_sub_stmt_error since we
-    assume this is never called if the fatal error is set.
-    @todo: To silence an error, one should use Internal_error_handler
-    mechanism. In future this function will be removed.
-  */
-  inline void clear_error(bool full= false)
-  {
-    if (main_da.is_error())
-      main_da.reset_diagnostics_area();
-
-    if (full)
-    {
-      drizzle_reset_errors(this, true);
-    }
-  }
-
-  void clearDiagnostics()
-  {
-    main_da.reset_diagnostics_area();
-  }
-
-  /**
-    Mark the current error as fatal. Warning: this does not
-    set any error, it sets a property of the error, so must be
-    followed or prefixed with my_error().
-  */
-  inline void fatal_error()
-  {
-    assert(main_da.is_error());
-    is_fatal_error= true;
-  }
-  /**
-    true if there is an error in the error stack.
-
-    Please use this method instead of direct access to
-    net.report_error.
-
-    If true, the current (sub)-statement should be aborted.
-    The main difference between this member and is_fatal_error
-    is that a fatal error can not be handled by a stored
-    procedure continue handler, whereas a normal error can.
-
-    To raise this flag, use my_error().
-  */
-  inline bool is_error() const { return main_da.is_error(); }
+  void clear_error(bool full= false);
+  void clearDiagnostics();
+  void fatal_error();
+  bool is_error() const;
+
   inline const CHARSET_INFO *charset() { return default_charset_info; }
 
   /**
@@ -1404,22 +1361,8 @@
   void mark_used_tables_as_free_for_reuse(Table *table);
 
 public:
-
-  /** A short cut for session->main_da.set_ok_status(). */
-  inline void my_ok(ha_rows affected_rows= 0, ha_rows found_rows_arg= 0,
-                    uint64_t passed_id= 0, const char *message= NULL)
-  {
-    main_da.set_ok_status(this, affected_rows, found_rows_arg, passed_id, message);
-  }
-
-
-  /** A short cut for session->main_da.set_eof_status(). */
-
-  inline void my_eof()
-  {
-    main_da.set_eof_status(this);
-  }
-
+  void my_ok(ha_rows affected_rows= 0, ha_rows found_rows_arg= 0, uint64_t passed_id= 0, const char *message= NULL);
+  void my_eof();
   bool add_item_to_list(Item *item);
   bool add_value_to_list(Item *value);
   bool add_order_to_list(Item *item, bool asc);

=== modified file 'drizzled/sql_delete.cc'
--- drizzled/sql_delete.cc	2011-03-14 17:27:03 +0000
+++ drizzled/sql_delete.cc	2011-03-15 20:23:53 +0000
@@ -181,7 +181,7 @@
      * Resetting the Diagnostic area to prevent
      * lp bug# 439719
      */
-    session->main_da.reset_diagnostics_area();
+    session->main_da().reset_diagnostics_area();
     session->my_ok((ha_rows) session->rowCount());
     /*
       We don't need to call reset_auto_increment in this case, because
@@ -347,7 +347,7 @@
      * Resetting the Diagnostic area to prevent
      * lp bug# 439719
      */
-    session->main_da.reset_diagnostics_area();
+    session->main_da().reset_diagnostics_area();
     session->my_ok((ha_rows) session->rowCount());
   }
   session->status_var.deleted_row_count+= deleted;

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2011-03-10 13:40:36 +0000
+++ drizzled/sql_parse.cc	2011-03-15 20:23:53 +0000
@@ -246,7 +246,7 @@
   }
   case COM_QUIT:
     /* We don't calculate statistics for this command */
-    session->main_da.disable_status();              // Don't send anything back
+    session->main_da().disable_status();              // Don't send anything back
     error= true;					// End server
     break;
   case COM_KILL:
@@ -289,10 +289,10 @@
   }
 
   /* If commit fails, we should be able to reset the OK status. */
-  session->main_da.can_overwrite_status= true;
+  session->main_da().can_overwrite_status= true;
   TransactionServices &transaction_services= TransactionServices::singleton();
   transaction_services.autocommitOrRollback(*session, session->is_error());
-  session->main_da.can_overwrite_status= false;
+  session->main_da().can_overwrite_status= false;
 
   session->transaction.stmt.reset();
 
@@ -300,7 +300,7 @@
   /* report error issued during command execution */
   if (session->killed_errno())
   {
-    if (! session->main_da.is_set())
+    if (! session->main_da().is_set())
       session->send_kill_message();
   }
   if (session->getKilled() == Session::KILL_QUERY || session->getKilled() == Session::KILL_BAD_DATA)
@@ -310,14 +310,14 @@
   }
 
   /* Can not be true, but do not take chances in production. */
-  assert(! session->main_da.is_sent);
+  assert(! session->main_da().is_sent);
 
-  switch (session->main_da.status())
+  switch (session->main_da().status())
   {
   case Diagnostics_area::DA_ERROR:
     /* The query failed, send error to log and abort bootstrap. */
-    session->getClient()->sendError(session->main_da.sql_errno(),
-                               session->main_da.message());
+    session->getClient()->sendError(session->main_da().sql_errno(),
+                               session->main_da().message());
     break;
 
   case Diagnostics_area::DA_EOF:
@@ -337,7 +337,7 @@
     break;
   }
 
-  session->main_da.is_sent= true;
+  session->main_da().is_sent= true;
 
   session->set_proc_info("closing tables");
   /* Free tables */

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2011-03-14 17:27:03 +0000
+++ drizzled/sql_update.cc	2011-03-15 20:23:53 +0000
@@ -248,7 +248,7 @@
      * Resetting the Diagnostic area to prevent
      * lp bug# 439719
      */
-    session->main_da.reset_diagnostics_area();
+    session->main_da().reset_diagnostics_area();
     free_underlaid_joins(session, select_lex);
     if (error || session->is_error())
     {
@@ -577,7 +577,7 @@
      * Resetting the Diagnostic area to prevent
      * lp bug# 439719
      */
-    session->main_da.reset_diagnostics_area();
+    session->main_da().reset_diagnostics_area();
     session->my_ok((ulong) session->rowCount(), found, id, buff);
     session->status_var.updated_row_count+= session->rowCount();
   }

=== modified file 'plugin/mysql_protocol/mysql_protocol.cc'
--- plugin/mysql_protocol/mysql_protocol.cc	2011-03-05 21:45:08 +0000
+++ plugin/mysql_protocol/mysql_protocol.cc	2011-03-15 20:23:53 +0000
@@ -201,7 +201,7 @@
   }
   else
   {
-    sendError(session->main_da.sql_errno(), session->main_da.message());
+    sendError(session->main_da().sql_errno(), session->main_da().message());
     counters->failedConnections.increment();
     return false;
   }
@@ -236,8 +236,8 @@
 
     if(net.last_errno== ER_NET_PACKET_TOO_LARGE)
       my_error(ER_NET_PACKET_TOO_LARGE, MYF(0));
-    if (session->main_da.status() == Diagnostics_area::DA_ERROR)
-      sendError(session->main_da.sql_errno(), session->main_da.message());
+    if (session->main_da().status() == Diagnostics_area::DA_ERROR)
+      sendError(session->main_da().sql_errno(), session->main_da().message());
     else
       sendOK();
 
@@ -342,17 +342,17 @@
   }
 
   buff[0]=0;                    // No fields
-  if (session->main_da.status() == Diagnostics_area::DA_OK)
+  if (session->main_da().status() == Diagnostics_area::DA_OK)
   {
-    if (client_capabilities & CLIENT_FOUND_ROWS && session->main_da.found_rows())
-      pos=storeLength(buff+1,session->main_da.found_rows());
+    if (client_capabilities & CLIENT_FOUND_ROWS && session->main_da().found_rows())
+      pos=storeLength(buff+1,session->main_da().found_rows());
     else
-      pos=storeLength(buff+1,session->main_da.affected_rows());
-    pos=storeLength(pos, session->main_da.last_insert_id());
-    int2store(pos, session->main_da.server_status());
+      pos=storeLength(buff+1,session->main_da().affected_rows());
+    pos=storeLength(pos, session->main_da().last_insert_id());
+    int2store(pos, session->main_da().server_status());
     pos+=2;
-    tmp= min(session->main_da.total_warn_count(), (uint32_t)65535);
-    message= session->main_da.message();
+    tmp= min(session->main_da().total_warn_count(), (uint32_t)65535);
+    message= session->main_da().message();
   }
   else
   {
@@ -367,7 +367,7 @@
   int2store(pos, tmp);
   pos+= 2;
 
-  session->main_da.can_overwrite_status= true;
+  session->main_da().can_overwrite_status= true;
 
   if (message && message[0])
   {
@@ -379,7 +379,7 @@
   drizzleclient_net_write(&net, buff, (size_t) (pos-buff));
   drizzleclient_net_flush(&net);
 
-  session->main_da.can_overwrite_status= false;
+  session->main_da().can_overwrite_status= false;
 }
 
 /**
@@ -402,11 +402,11 @@
   /* Set to true if no active vio, to work well in case of --init-file */
   if (net.vio != 0)
   {
-    session->main_da.can_overwrite_status= true;
-    writeEOFPacket(session->main_da.server_status(),
-                   session->main_da.total_warn_count());
+    session->main_da().can_overwrite_status= true;
+    writeEOFPacket(session->main_da().server_status(),
+                   session->main_da().total_warn_count());
     drizzleclient_net_flush(&net);
-    session->main_da.can_overwrite_status= false;
+    session->main_da().can_overwrite_status= false;
   }
   packet.shrink(buffer_length.get());
 }
@@ -427,7 +427,7 @@
     It's one case when we can push an error even though there
     is an OK or EOF already.
   */
-  session->main_da.can_overwrite_status= true;
+  session->main_da().can_overwrite_status= true;
 
   /* Abort multi-result sets */
   session->server_status&= ~SERVER_MORE_RESULTS_EXISTS;
@@ -463,7 +463,7 @@
 
   drizzleclient_net_flush(&net);
 
-  session->main_da.can_overwrite_status= false;
+  session->main_da().can_overwrite_status= false;
 }
 
 /**

